@@ -213,30 +213,31 @@ Manager::Manager()
   connect(&metadata_manager, &MetadataManager::defaultSourceChanged, [&](const QString& name) {
     defaultInputDeviceName = name;
 
+    if (DbStreamInputs::useDefaultInputDevice() || DbStreamInputs::inputDevice().isEmpty()) {
+      DbStreamInputs::setInputDevice(name);
+    }
+
     Q_EMIT defaultInputDeviceNameChanged();
-    Q_EMIT newDefaultSourceName(name);
   });
 
   connect(&metadata_manager, &MetadataManager::defaultSinkChanged, [&](const QString& name) {
     defaultOutputDeviceName = name;
 
+    if (DbStreamOutputs::useDefaultOutputDevice() || DbStreamOutputs::outputDevice().isEmpty()) {
+      DbStreamOutputs::setOutputDevice(name);
+    }
+
     Q_EMIT defaultOutputDeviceNameChanged();
-    Q_EMIT newDefaultSinkName(name);
   });
 
   connect(&node_manager, &NodeManager::sourceAdded, [&](NodeInfo node) { Q_EMIT sourceAdded(node); });
 
   connect(&node_manager, &NodeManager::sinkAdded, [&](NodeInfo node) { Q_EMIT sinkAdded(node); });
 
-  connect(&node_manager, &NodeManager::sourceProfileNameChanged,
-          [&](NodeInfo node) { Q_EMIT sourceRouteChanged(node); });
-
-  connect(&node_manager, &NodeManager::sinkProfileNameChanged, [&](NodeInfo node) { Q_EMIT sinkRouteChanged(node); });
-
   connect(&link_manager, &LinkManager::linkChanged, [&](LinkInfo link) { Q_EMIT linkChanged(link); });
 
   connect(&device_manager, &DeviceManager::inputRouteChanged, [&](DeviceInfo device) {
-    QTimer::singleShot(db::Main::presetsAutoloadInterval(), this, [&, device]() {
+    QTimer::singleShot(DbMain::presetsAutoloadInterval(), this, [&, device]() {
       auto nodes = model_nodes.get_nodes_by_device_id(device.id);
 
       if (nodes.empty()) {
@@ -245,18 +246,20 @@ Manager::Manager()
       }
 
       for (auto& node : nodes) {
-        node.device_route_name = device.input_route_name;
-        node.device_route_description = device.input_route_description;
+        if (node.media_class == tags::pipewire::media_class::source) {
+          node.device_route_name = device.input_route_name;
+          node.device_route_description = device.input_route_description;
 
-        model_nodes.update_info(node);
+          model_nodes.update_info(node);
 
-        Q_EMIT sourceRouteChanged(node);
+          Q_EMIT sourceRouteChanged(node);
+        }
       }
     });
   });
 
   connect(&device_manager, &DeviceManager::outputRouteChanged, [&](DeviceInfo device) {
-    QTimer::singleShot(db::Main::presetsAutoloadInterval(), this, [&, device]() {
+    QTimer::singleShot(DbMain::presetsAutoloadInterval(), this, [&, device]() {
       auto nodes = model_nodes.get_nodes_by_device_id(device.id);
 
       if (nodes.empty()) {
@@ -265,12 +268,14 @@ Manager::Manager()
       }
 
       for (auto& node : nodes) {
-        node.device_route_name = device.output_route_name;
-        node.device_route_description = device.output_route_description;
+        if (node.media_class == tags::pipewire::media_class::sink) {
+          node.device_route_name = device.output_route_name;
+          node.device_route_description = device.output_route_description;
 
-        model_nodes.update_info(node);
+          model_nodes.update_info(node);
 
-        Q_EMIT sinkRouteChanged(node);
+          Q_EMIT sinkRouteChanged(node);
+        }
       }
     });
   });
@@ -366,11 +371,11 @@ Manager::Manager()
 
   for (const auto& node : model_nodes.get_list()) {
     if (node.media_class == tags::pipewire::media_class::output_stream) {
-      if (db::Main::processAllOutputs() && !node.is_blocklisted) {
+      if (DbMain::processAllOutputs() && !node.is_blocklisted) {
         connectStreamOutput(node.id);
       }
     } else if (node.media_class == tags::pipewire::media_class::input_stream) {
-      if (db::Main::processAllInputs() && !node.is_blocklisted) {
+      if (DbMain::processAllInputs() && !node.is_blocklisted) {
         connectStreamInput(node.id);
       }
     }
